@@ -145,7 +145,9 @@ detfct.fit.opt <- function(ddfobj, optim.options, bounds, misc.options,
                           ddfobj=ddfobj, misc.options=misc.options,
                           control=list(trace=as.integer(showit),
                                        tol=misc.options$mono.tol,
-                                       delta=misc.options$mono.delta)),
+                                       delta=misc.options$mono.delta,
+                                       outer.iter=misc.options$mono.outer.iter)
+                         ),
                     silent=TRUE))
       }else{
         lt <- try(solnp(pars=initialvalues, fun=flnl, eqfun=NULL, eqB=NULL,
@@ -155,95 +157,112 @@ detfct.fit.opt <- function(ddfobj, optim.options, bounds, misc.options,
                         ddfobj=ddfobj, misc.options=misc.options,
                         control=list(trace=as.integer(showit),
                                      tol=misc.options$mono.tol,
-                                     delta=misc.options$mono.delta)))
+                                     delta=misc.options$mono.delta,
+                                     outer.iter=misc.options$mono.outer.iter)))
       }
 
-      # we can use the gosolnp() function to explore the parameter space
-      # randomly...
-      if(misc.options$mono.random.start){
-        if(length(initialvalues)>1){
-          # gosolnp doesn't work when there is only 1 parameter
-          # since there is a bug that leaves the optimisation with a vector
-          # when it is expecting a matrix. To avoid this bug, don't do the
-          # multiple start points in that case (should only be unif+cos(1))
+      # only do something more complicated if we didn't converge above!
+      if(inherits(lt, "try-error") || lt$convergence!=0){
+        # we can use the gosolnp() function to explore the parameter space
+        # randomly...
+        if(misc.options$mono.random.start){
+          if(length(initialvalues)>1){
+            # gosolnp doesn't work when there is only 1 parameter
+            # since there is a bug that leaves the optimisation with a vector
+            # when it is expecting a matrix. To avoid this bug, don't do the
+            # multiple start points in that case (should only be unif+cos(1))
 
+            if(showit==0){
+              lt2 <- suppressWarnings(
+                     try(gosolnp(pars=initialvalues, fun=flnl,
+                                 eqfun=NULL, eqB=NULL,
+                                 ineqfun=flnl.constr,
+                                 ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
+                                 LB=lowerbounds, UB=upperbounds,
+                                 ddfobj=ddfobj, misc.options=misc.options,
+                                 control=list(trace=as.integer(showit),
+                                              tol=misc.options$mono.tol,
+                                              delta=misc.options$mono.delta,
+                                              outer.iter=misc.options$mono.outer.iter),
+                                 distr = rep(1, length(lowerbounds)),
+                                 n.restarts = 2, n.sim = 200,
+                                 rseed=as.integer(runif(1)*1e9)),
+                          silent=TRUE))
+            }else{
+              lt2 <- try(gosolnp(pars=initialvalues, fun=flnl,
+                                 eqfun=NULL, eqB=NULL,
+                                 ineqfun=flnl.constr,
+                                 ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
+                                 LB=lowerbounds, UB=upperbounds,
+                                 ddfobj=ddfobj, misc.options=misc.options,
+                                 control=list(trace=as.integer(showit),
+                                              tol=misc.options$mono.tol,
+                                              delta=misc.options$mono.delta,
+                                              outer.iter=misc.options$mono.outer.iter),
+                                 distr = rep(1, length(lowerbounds)),
+                                 n.restarts = 2, n.sim = 200,
+                                 rseed=as.integer(runif(1)*1e9)))
+            }
+
+            # was this better than the first time
+            if(!inherits(lt2, "try-error")){
+              if(inherits(lt, "try-error") ||
+                 (!is.na(lt2$values[length(lt2$values)]) &&
+                 (lt2$values[length(lt2$values)] <
+                  lt$values[length(lt$values)]))){
+                lt <- lt2
+              }
+            } # end "was it better" check
+          } # end par length check
+        }else{
+          # otherwise we do non-random par space exploration using a grid
+
+          # n.sim=200 for gosolnp, so we want a comparable systematic grid
+          # so we want n.notsim=200= (seq len)^(par dimensions)
+          # => ~~ 200^(1/(par dimensions))
+          # but still need some resolution on the grid, so make the min
+          # sequence be length 4??
+          n.notsim <- max(c(4, ceiling(200^(1/length(lowerbounds)))))
+          # create a sequence in each parameters direction
+          par_grid <- apply(cbind(lowerbounds, upperbounds), 1,
+                            \(x) seq(x[1], x[2], length.out=n.notsim))
+          # trim the extremes
+          par_grid <- par_grid[-c(1, nrow(par_grid)), , drop=FALSE]
+          # then expand out the options
+          par_grid <- as.matrix(expand.grid(as.data.frame(par_grid)))
+          # add in the initialvalues pars too
+          par_grid <- rbind(par_grid, initialvalues)
+
+          # small initialvalues lead to errors in solnp, so work around that
+          par_grid[abs(par_grid)<1e-2] <- sign(par_grid[abs(par_grid)<1e-2])*1e-2
+
+          flnl_wrap <- function(...){
+            e <- try(flnl(...), silent=TRUE)
+            if(inherits(e, "try-error")){
+              return(NA)
+            }
+            e
+          }
+          grid_lnls <- apply(par_grid, 1, flnl_wrap,
+                             ddfobj=ddfobj, misc.options=misc.options)
+          igrid <- which.min(grid_lnls)
+
+          # now run at best value
           if(showit==0){
-            lt2 <- suppressWarnings(
-                   try(gosolnp(pars=initialvalues, fun=flnl,
-                               eqfun=NULL, eqB=NULL,
-                               ineqfun=flnl.constr,
-                               ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
-                               LB=lowerbounds, UB=upperbounds,
-                               ddfobj=ddfobj, misc.options=misc.options,
-                               control=list(trace=as.integer(showit),
-                                            tol=misc.options$mono.tol,
-                                            delta=misc.options$mono.delta),
-                               distr = rep(1, length(lowerbounds)),
-                               n.restarts = 2, n.sim = 200,
-                               rseed=as.integer(runif(1)*1e9)),
+            lt <- suppressWarnings(
+                    try(solnp(pars=par_grid[igrid, ], fun=flnl,
+                              eqfun=NULL, eqB=NULL,
+                              ineqfun=flnl.constr,
+                              ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
+                              LB=lowerbounds, UB=upperbounds,
+                              ddfobj=ddfobj, misc.options=misc.options,
+                              control=list(trace=as.integer(showit),
+                                           tol=misc.options$mono.tol,
+                                           delta=misc.options$mono.delta,
+                                           outer.iter=misc.options$mono.outer.iter)),
                         silent=TRUE))
           }else{
-            lt2 <- try(gosolnp(pars=initialvalues, fun=flnl,
-                               eqfun=NULL, eqB=NULL,
-                               ineqfun=flnl.constr,
-                               ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
-                               LB=lowerbounds, UB=upperbounds,
-                               ddfobj=ddfobj, misc.options=misc.options,
-                               control=list(trace=as.integer(showit),
-                                            tol=misc.options$mono.tol,
-                                            delta=misc.options$mono.delta),
-                               distr = rep(1, length(lowerbounds)),
-                               n.restarts = 2, n.sim = 200,
-                               rseed=as.integer(runif(1)*1e9)))
-          }
-
-          # was this better than the first time
-          if(!inherits(lt2, "try-error")){
-            if(inherits(lt, "try-error") ||
-               (!is.na(lt2$values[length(lt2$values)]) &&
-               (lt2$values[length(lt2$values)] <
-                lt$values[length(lt$values)]))){
-              lt <- lt2
-            }
-          } # end "was it better" check
-        } # end par length check
-      }else{
-        # otherwise we do non-random par space exploration using a grid
-
-        # n.sim=200 for gosolnp, so we want a comparable systematic grid
-        # so we want n.notsim=200= (seq len)^(par dimensions)
-        # => ~~ 200^(1/(par dimensions))
-        # but still need some resolution on the grid, so make the min
-        # sequence be length 4??
-        n.notsim <- max(c(4, ceiling(200^(1/length(lowerbounds)))))
-        # create a sequence in each parameters direction
-        par_grid <- apply(cbind(lowerbounds, upperbounds), 1,
-                          \(x) seq(x[1], x[2], length.out=n.notsim))
-        # trim the extremes
-        par_grid <- par_grid[-c(1, nrow(par_grid)), , drop=FALSE]
-        # then expand out the options
-        par_grid <- as.matrix(expand.grid(as.data.frame(par_grid)))
-        # add in the initialvalues pars too
-        par_grid <- rbind(par_grid, initialvalues)
-
-        # small initialvalues lead to errors in solnp, so work around that
-        par_grid[abs(par_grid)<1e-2] <- sign(par_grid[abs(par_grid)<1e-2])*1e-2
-
-        flnl_wrap <- function(...){
-          e <- try(flnl(...), silent=TRUE)
-          if(inherits(e, "try-error")){
-            return(NA)
-          }
-          e
-        }
-        grid_lnls <- apply(par_grid, 1, flnl_wrap,
-                           ddfobj=ddfobj, misc.options=misc.options)
-        igrid <- which.min(grid_lnls)
-
-        # now run at best value
-        if(showit==0){
-          lt <- suppressWarnings(
-                  try(solnp(pars=par_grid[igrid, ], fun=flnl,
+            lt <- try(solnp(pars=par_grid[igrid, ], fun=flnl,
                             eqfun=NULL, eqB=NULL,
                             ineqfun=flnl.constr,
                             ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
@@ -251,20 +270,11 @@ detfct.fit.opt <- function(ddfobj, optim.options, bounds, misc.options,
                             ddfobj=ddfobj, misc.options=misc.options,
                             control=list(trace=as.integer(showit),
                                          tol=misc.options$mono.tol,
-                                         delta=misc.options$mono.delta)),
-                      silent=TRUE))
-        }else{
-          lt <- try(solnp(pars=par_grid[igrid, ], fun=flnl,
-                          eqfun=NULL, eqB=NULL,
-                          ineqfun=flnl.constr,
-                          ineqLB=lowerbounds.ic, ineqUB=upperbounds.ic,
-                          LB=lowerbounds, UB=upperbounds,
-                          ddfobj=ddfobj, misc.options=misc.options,
-                          control=list(trace=as.integer(showit),
-                                       tol=misc.options$mono.tol,
-                                       delta=misc.options$mono.delta)))
-        } # end showit status
-      } # end random vs. non-random par space exploration
+                                         delta=misc.options$mono.delta,
+                                         outer.iter=misc.options$mono.outer.iter)))
+          } # end showit status
+        } # end random vs. non-random par space exploration
+      } # end if solnp didn't converge the first time
 
       # if that failed then make a dummy object
       if(inherits(lt, "try-error")){
@@ -277,22 +287,11 @@ detfct.fit.opt <- function(ddfobj, optim.options, bounds, misc.options,
           cat("DEBUG: Optimisation failed, ignoring and carrying on...\n")
         }
       }else{
-        # above gosolnp code stores best lnl as last value
-        # recover that information!
-        lt$conv <- lt$convergence[length(lt$values)]
-        lt$par <- lt$pars[length(lt$values)]
+        lt$conv <- lt$convergence
+        lt$par <- lt$pars
         lt$value <- lt$values[length(lt$values)]
         lt$message <- ""
       }
-
-      # re-jig some stuff so that this looks like an optim result...
-      lt$conv <- lt$convergence
-      lt$par <- lt$pars
-      lt$value <- lt$values[length(lt$values)]
-      lt$message <- ""
-      # note that this gives the *augmented* hessian! Not what we want
-      #attr(lt, "details") <- list(nhatend=lt$hessian)
-
     ## end monotonically constrained estimation
     }else{
     ## unconstrained optimisation
